# MMLM (Multi-Modality Learning Model)

## Introduction

## Usage

data format(input/output):  
`instruction <audio> audio file path </audio> instruction <image> image file path </image> instruction`
